.. pitchtools documentation master file, created by
   sphinx-quickstart on Sun May  2 01:39:34 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pitchtools's documentation!
======================================

.. automodapi:: pitchtools
    :no-inheritance-diagram:
